@@ -1,10 +1,7 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
+import ast
 import json
 import logging
 import os.path
-from distutils.util import strtobool
 
 from flask import abort, request, url_for
 from jinja2.utils import contextfunction
@@ -35,18 +32,18 @@ def jsonprint(value):
 
 
 def get_db_version(puppetdb):
-    '''
+    """
     Get the version of puppetdb.  Version form 3.2 query
     interface is slightly different on mbeans
-    '''
+    """
     ver = ()
     try:
         version = puppetdb.current_version()
         (major, minor, build) = [int(x) for x in version.split('.')]
         ver = (major, minor, build)
         log.info("PuppetDB Version %d.%d.%d" % (major, minor, build))
-    except ValueError as e:
-        log.error("Unable to determine version from string: '%s'" % version)
+    except ValueError:
+        log.error("Unable to determine version from string: '%s'" % puppetdb.current_version())
         ver = (4, 2, 0)
     except HTTPError as e:
         log.error(str(e))
@@ -57,6 +54,20 @@ def get_db_version(puppetdb):
     return ver
 
 
+def parse_python(value: str):
+    """
+    :param value: any string, number, bool, list or a dict
+                  casted to a string (f.e. "{'up': ['eth0'], (...)}")
+    :return: the same value but with a proper type
+    """
+    try:
+        return ast.literal_eval(value)
+    except ValueError:
+        return str(value)
+    except SyntaxError:
+        return str(value)
+
+
 def formatvalue(value):
     if isinstance(value, str):
         return value
@@ -71,36 +82,38 @@ def formatvalue(value):
         return str(value)
 
 
-def prettyprint(value):
-    html = '<table class="ui basic fixed sortable table"><thead><tr>'
-
-    # Get keys
-    for k in value[0]:
-        html += "<th>" + k + "</th>"
-
-    html += "</tr></thead><tbody>"
-
-    for e in value:
-        html += "<tr>"
-        for k in e:
-            html += "<td>" + formatvalue(e[k]) + "</td>"
-        html += "</tr>"
-
-    html += "</tbody></table>"
-    return (html)
-
-
 def get_or_abort(func, *args, **kwargs):
+    """Perform a backend request and handle all the errors,
+    """
+    return _do_get_or_abort(False, func, *args, **kwargs)
+
+
+def get_or_abort_except_client_errors(func, *args, **kwargs):
+    """Perform a backend request and handle the errors,
+    but with a chance to react to client errors (HTTP 400-499).
+    """
+    return _do_get_or_abort(True, func, *args, **kwargs)
+
+
+def _do_get_or_abort(reraise_client_error: bool, func, *args, **kwargs):
     """Execute the function with its arguments and handle the possible
     errors that might occur.
 
-    In this case, if we get an exception we simply abort the request.
+    If reraise_client_error is True then if the HTTP response status code
+    indicates that it was a client side error - then re-raise it.
+
+    In all other cases if we get an exception we simply abort the request.
     """
     try:
         return func(*args, **kwargs)
     except HTTPError as e:
-        log.error(str(e))
-        abort(e.response.status_code)
+        if reraise_client_error and 400 <= e.response.status_code <= 499:
+            # it's a client side error, so reraise it to show the user
+            log.warning(str(e))
+            raise
+        else:
+            log.error(str(e))
+            abort(e.response.status_code)
     except ConnectionError as e:
         log.error(str(e))
         abort(500)
@@ -126,13 +139,35 @@ def yield_or_stop(generator):
             return
 
 
-def is_bool(b):
-    try:
-        bool(strtobool(b))
-        return True
-    except ValueError:
-        return False
-    except TypeError:
-        return False
-    except AttributeError:
-        return False
+def quote_columns_data(data: str) -> str:
+    """When projecting Queries using dot notation (f.e. inventory [ facts.osfamily ])
+    we need to quote the dot in such column name for the DataTables library or it will
+    interpret the dot a way to get into a nested results object.
+
+    See https://datatables.net/reference/option/columns.data#Types."""
+    return data.replace('.', '\\.')
+
+
+def check_env(env, envs):
+    if env != '*' and env not in envs:
+        abort(404)
+
+
+def metric_params(db_version):
+    query_type = ''
+
+    # Puppet Server is enforcing new metrics API (v2)
+    # starting with versions 6.9.1, 5.3.12, and 5.2.13
+    if (db_version > (6, 9, 0) or
+            ((5, 3, 11) < db_version < (6, 0, 0)) or
+            ((5, 2, 12) < db_version < (5, 3, 10))):
+        metric_version = 'v2'
+    else:
+        metric_version = 'v1'
+
+    # Puppet DB version changed the query format from 3.2.0
+    # to 4.0 when querying mbeans
+    if db_version < (4, 0, 0):
+        query_type = 'type=default,'
+
+    return query_type, metric_version
