@@ -2,22 +2,13 @@ import os
 
 import pytest
 
-import puppetboard.core
 from puppetboard import docker_settings
 
-try:
-    import future.utils
-except:
-    pass
-
-try:
-    from importlib import reload as reload
-except:
-    pass
+from importlib import reload as reload
 
 
 @pytest.fixture(scope='function')
-def cleanUpEnv(request):
+def cleanup_env(request):
     for env_var in dir(docker_settings):
         if (env_var.startswith('__') or env_var.startswith('_') or
                 env_var.islower()):
@@ -29,12 +20,12 @@ def cleanUpEnv(request):
     return
 
 
-def test_default_host_port(cleanUpEnv):
+def test_default_host_port(cleanup_env):
     assert docker_settings.PUPPETDB_HOST == 'puppetdb'
     assert docker_settings.PUPPETDB_PORT == 8080
 
 
-def test_set_host_port(cleanUpEnv):
+def test_set_host_port(cleanup_env):
     os.environ['PUPPETDB_HOST'] = 'puppetdb2'
     os.environ['PUPPETDB_PORT'] = '9081'
     reload(docker_settings)
@@ -42,13 +33,13 @@ def test_set_host_port(cleanUpEnv):
     assert docker_settings.PUPPETDB_PORT == 9081
 
 
-def test_set_proto(cleanUpEnv):
+def test_set_proto(cleanup_env):
     os.environ['PUPPETDB_PROTO'] = 'https'
     reload(docker_settings)
     assert docker_settings.PUPPETDB_PROTO == 'https'
 
 
-def test_cert_true_test(cleanUpEnv):
+def test_cert_true_test(cleanup_env):
     os.environ['PUPPETDB_SSL_VERIFY'] = 'True'
     reload(docker_settings)
     assert docker_settings.PUPPETDB_SSL_VERIFY is True
@@ -57,7 +48,7 @@ def test_cert_true_test(cleanUpEnv):
     assert docker_settings.PUPPETDB_SSL_VERIFY is True
 
 
-def test_cert_false_test(cleanUpEnv):
+def test_cert_false_test(cleanup_env):
     os.environ['PUPPETDB_SSL_VERIFY'] = 'False'
     reload(docker_settings)
     assert docker_settings.PUPPETDB_SSL_VERIFY is False
@@ -66,13 +57,43 @@ def test_cert_false_test(cleanUpEnv):
     assert docker_settings.PUPPETDB_SSL_VERIFY is False
 
 
-def test_cert_path(cleanUpEnv):
+def test_cert_path(cleanup_env):
     ca_file = '/usr/ssl/path/ca.pem'
     os.environ['PUPPETDB_SSL_VERIFY'] = ca_file
     reload(docker_settings)
     assert docker_settings.PUPPETDB_SSL_VERIFY == ca_file
 
 
+def test_cert_to_file(cleanup_env):
+    import tempfile
+    cert_string = '-----BEGIN CERTIFICATE-----\nMIIFkjCCA3qgAwf'
+
+    os.environ['PUPPETDB_KEY'] = cert_string
+    reload(docker_settings)
+    assert docker_settings.PUPPETDB_KEY.startswith(tempfile.gettempdir())
+
+    with open(docker_settings.PUPPETDB_KEY) as test_cert_file:
+        assert test_cert_file.read() == '-----BEGIN CERTIFICATE-----\nMIIFkjCCA3qgAwf'
+
+    # Clean up the generated file
+    os.unlink(docker_settings.PUPPETDB_KEY)
+
+
+def test_cert_to_file_base64(cleanup_env):
+    import tempfile
+    cert_string = 'LS0tLS1CRUdJTiBDRVJUSUZJQ0FURS0tLS0tCk1JSUZrakNDQTNxZ0F3SUI='
+
+    os.environ['PUPPETDB_KEY'] = cert_string
+    reload(docker_settings)
+    assert docker_settings.PUPPETDB_KEY.startswith(tempfile.gettempdir())
+
+    with open(docker_settings.PUPPETDB_KEY) as test_cert_file:
+        assert test_cert_file.read() == '-----BEGIN CERTIFICATE-----\nMIIFkjCCA3qgAwIB'
+
+    # Clean up the generated file
+    os.unlink(docker_settings.PUPPETDB_KEY)
+
+
 def validate_facts(facts):
     assert isinstance(facts, list)
     assert len(facts) > 0
@@ -81,23 +102,23 @@ def validate_facts(facts):
         assert len(map) == 2
 
 
-def test_inventory_facts_default(cleanUpEnv):
+def test_inventory_facts_default(cleanup_env):
     validate_facts(docker_settings.INVENTORY_FACTS)
 
 
-def test_invtory_facts_custom(cleanUpEnv):
+def test_invtory_facts_custom(cleanup_env):
     os.environ['INVENTORY_FACTS'] = "A, B, C, D"
     reload(docker_settings)
     validate_facts(docker_settings.INVENTORY_FACTS)
 
 
-def test_graph_facts_defautl(cleanUpEnv):
+def test_graph_facts_defautl(cleanup_env):
     facts = docker_settings.GRAPH_FACTS
     assert isinstance(facts, list)
     assert 'puppetversion' in facts
 
 
-def test_graph_facts_custom(cleanUpEnv):
+def test_graph_facts_custom(cleanup_env):
     os.environ['GRAPH_FACTS'] = "architecture, puppetversion, extra"
     reload(docker_settings)
     facts = docker_settings.GRAPH_FACTS
@@ -108,27 +129,17 @@ def test_graph_facts_custom(cleanUpEnv):
     assert 'extra' in facts
 
 
-def test_bad_log_value(cleanUpEnv, mocker):
-    os.environ['LOGLEVEL'] = 'g'
-    os.environ['PUPPETBOARD_SETTINGS'] = '../puppetboard/docker_settings.py'
-    reload(docker_settings)
-
-    puppetboard.core.APP = None
-    with pytest.raises(ValueError) as error:
-        puppetboard.core.get_app()
-
-
-def test_default_table_selctor(cleanUpEnv):
+def test_default_table_selctor(cleanup_env):
     assert [10, 20, 50, 100, 500] == docker_settings.TABLE_COUNT_SELECTOR
 
 
-def test_env_table_selector(cleanUpEnv):
+def test_env_table_selector(cleanup_env):
     os.environ['TABLE_COUNT_SELECTOR'] = '5,15,25'
     reload(docker_settings)
     assert [5, 15, 25] == docker_settings.TABLE_COUNT_SELECTOR
 
 
-def test_env_column_options(cleanUpEnv):
+def test_env_column_options(cleanup_env):
     os.environ['DISPLAYED_METRICS'] = 'resources.total, events.failure'
 
     reload(docker_settings)
